==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/delivery/__openerp__.py <==
# -*- coding: utf-8 -*-
################################################################################
#
# Copyright (C) 2009-2015 All Rights Reserved. Luiz Fernando Maciel Franca
#              www.siginformatica.com.br <luiz[at]siginformatica.com.br>
#                                -------
#
# Copyleft (CC) 2015, Creative Commons
# Atribuicao-Nao Comercial-Compartilhada Igual 3 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
#
################################################################################

# noinspection PyStatementEffect
{
    'name': 'delivery',
    'version': '7.0.21.12.14',
    'author': 'Sig Informatica Ltda',
    'website': 'http: //www.sigsolucoes.net.br',
    'category': 'Vendas',
    'description': 'Sistema de Gestão de delivery',
    'license': 'Other proprietary',
    'depends': ['vendas'],
    'init_xml': [],
    'demo_xml': [],
    'data': ['views/entregador.xml',
             'views/entregas.xml',
             'views/delivery_acertos_view.xml',
             'inherit/estoquepedidos/pedido_capa_view.xml',
             'inherit/estoquepedidos/pedido_montagem_view.xml',
             'inherit/financeiro/financeiro_parametros_view.xml',
             'inherit/financeiro/gerencial_movimento_view.xml',
             'security/delivery_security.xml',
             'security/ir.model.access.csv',
             'views/actions.xml',
             'views/menu.xml',
             'wizard/comissao_entrega_view.xml',
             'wizard/actions.xml',
             'inherit/vendas/menu.xml'],
    'installable': True
}

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/delivery/__openerp__.py <==
# -*- coding: utf-8 -*-
################################################################################
#
# Copyright (C) 2009-2015 All Rights Reserved. Luiz Fernando Maciel Franca
#              www.siginformatica.com.br <luiz[at]siginformatica.com.br>
#                                -------
#
# Copyleft (CC) 2015, Creative Commons
# Atribuicao-Nao Comercial-Compartilhada Igual 3 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
#
################################################################################

# noinspection PyStatementEffect
{
    'name': 'delivery',
    'version': '7.0.2310.2',
    'author': 'Sig Informatica Ltda',
    'website': 'http: //www.sigsolucoes.net.br',
    'category': 'Vendas',
    'description': 'Sistema de Gestão de delivery',
    'license': 'Other proprietary',
    'depends': ['vendas'],
    'init_xml': [],
    'demo_xml': [],
    'data': ['views/entregador.xml',
             'views/entregas.xml',
             'views/delivery_acertos_view.xml',
             'inherit/estoquepedidos/pedido_capa_view.xml',
             'inherit/estoquepedidos/pedido_montagem_view.xml',
             'inherit/financeiro/financeiro_parametros_view.xml',
             'inherit/financeiro/gerencial_movimento_view.xml',
             'security/delivery_security.xml',
             'security/ir.model.access.csv',
             'views/actions.xml',
             'views/menu.xml',
             'wizard/comissao_entrega_view.xml',
             'wizard/actions.xml',
             'inherit/vendas/menu.xml'],
    'installable': True
}
